@@ -5,8 +5,19 @@
 udocker unit tests: CmdParser
 """
 
+import os
+import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from udocker.cmdparser import CmdParser
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class CmdParserTestCase(TestCase):
@@ -92,5 +103,6 @@ class CmdParserTestCase(TestCase):
     # def test_07__get_param(self):
     #     """Test07 CmdParser()._get_param()."""
 
+
 if __name__ == '__main__':
     main()
