@@ -3,9 +3,20 @@
 udocker unit tests: CommonLocalFileApi
 """
 
+import os
+import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from unittest.mock import Mock, patch
 from udocker.commonlocalfile import CommonLocalFileApi
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class CommonLocalFileApiTestCase(TestCase):
@@ -368,5 +379,6 @@ class CommonLocalFileApiTestCase(TestCase):
         status = clfapi._get_imagedir_type(tmp_imagedir)
         self.assertEqual(status, "Docker")
 
+
 if __name__ == '__main__':
     main()
