@@ -5,9 +5,21 @@
 udocker unit tests: Config
 """
 
+
+import os
+import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from unittest.mock import patch
 from udocker.config import Config
+import collections
+collections.Callable = collections.abc.Callable
 
 BUILTINS = "builtins"
 
@@ -84,5 +96,6 @@ class ConfigTestCase(TestCase):
         config.container()
         self.assertTrue(mock_fileover.called)
 
+
 if __name__ == '__main__':
     main()
