@@ -5,10 +5,21 @@
 udocker unit tests: ContainerStructure
 """
 
+import os
+import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from unittest.mock import patch, Mock
 from udocker.container.structure import ContainerStructure
-from udocker.config import Config
+from config import Config
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class ContainerStructureTestCase(TestCase):
