@@ -2,11 +2,22 @@
 """
 udocker unit tests: Msg
 """
+
+import os
 import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from unittest.mock import patch
 from io import StringIO
 from udocker.msg import Msg
+import collections
+collections.Callable = collections.abc.Callable
 
 STDOUT = sys.stdout
 STDERR = sys.stderr
@@ -18,7 +29,7 @@ def is_writable_file(obj):
     """Check if obj is a file."""
     try:
         obj.write("")
-    except(AttributeError, OSError, IOError):
+    except (AttributeError, OSError, IOError):
         return False
     else:
         return True
