@@ -3,9 +3,20 @@
 udocker unit tests: Unshare
 """
 
+import os
+import sys
+
+new_path = []
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
+new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
+new_path.extend(sys.path)
+sys.path = new_path
+
 from unittest import TestCase, main
 from unittest.mock import patch, MagicMock
 from udocker.helper.unshare import Unshare
+import collections
+collections.Callable = collections.abc.Callable
 
 
 class UnshareTestCase(TestCase):
