@@ -2,7 +2,7 @@
 """Configurations options and treatment/overrinding"""
 import os
 import sys
-from udocker.msg import Msg
+from msg import Msg
 
 # if Python 3
 if sys.version_info[0] >= 3:
@@ -148,15 +148,14 @@ class Config(object):
     # docker hub index
     conf['dockerio_index_url'] = "https://hub.docker.com"
     # docker hub registry
-    #conf['dockerio_registry_url'] = "https://registry.hub.docker.com"
+    # conf['dockerio_registry_url'] = "https://registry.hub.docker.com"
     conf['dockerio_registry_url'] = "https://registry-1.docker.io"
     # private repository v2
     # conf['dockerio_registry_url'] = "http://localhost:5000"
 
     # registries table
     conf['docker_registries'] = {"docker.io": [conf['dockerio_registry_url'],
-                                               conf['dockerio_index_url']],
-                                }
+                                 conf['dockerio_index_url']], }
 
     # nvidia files
     conf['nvi_etc_list'] = ['vulkan/icd.d/nvidia_icd.json',
@@ -206,7 +205,7 @@ class Config(object):
             self._conf_file_read(cfpath, ignore_keys)
 
         if Config.conf['topdir'] != Config.conf['homedir']:
-            cfpath = Config.conf['topdir'] + '/'  + Config.conf['config']
+            cfpath = Config.conf['topdir'] + '/' + Config.conf['config']
             if os.path.exists(cfpath):
                 self._conf_file_read(cfpath, ignore_keys)
 
@@ -257,13 +256,14 @@ class Config(object):
         Config.conf['fakechroot_expand_symlinks'] = \
             os.getenv("UDOCKER_FAKECHROOT_EXPAND_SYMLINKS",
                       str(Config.conf['fakechroot_expand_symlinks'])).lower()
+
         os.environ["PROOT_TMP_DIR"] = os.getenv("PROOT_TMP_DIR",
                                                 Config.conf['tmpdir'])
 
     def getconf(self, user_cfile="u.conf"):
         """Return all configuration variables"""
-        self._file_override(user_cfile) # Override with variables in conf file
-        self._env_override()          # Override with variables in environment
+        self._file_override(user_cfile)  # Override with variables in conf file
+        self._env_override()             # Override with variables in environment
 
     def container(self, user_cfile="u.conf"):
         """
