@@ -7,13 +7,13 @@ import sys
 import stat
 import json
 
-from udocker import is_genstr
-from udocker.config import Config
-from udocker.msg import Msg
-from udocker.utils.fileutil import FileUtil
-from udocker.utils.chksum import ChkSUM
-from udocker.utils.uprocess import Uprocess
-from udocker.helper.osinfo import OSInfo
+from genstr import is_genstr
+from config import Config
+from msg import Msg
+from helper.osinfo import OSInfo
+from utils.fileutil import FileUtil
+from utils.chksum import ChkSUM
+from utils.uprocess import Uprocess
 
 
 class LocalRepository(object):
@@ -86,10 +86,9 @@ class LocalRepository(object):
                 os.makedirs(self.libdir)
             if not os.path.exists(self.docdir):
                 os.makedirs(self.docdir)
-            if not (Config.conf['keystore'].startswith("/") or \
-                    os.path.exists(self.homedir)):
+            if not (Config.conf['keystore'].startswith("/") or os.path.exists(self.homedir)):
                 os.makedirs(self.homedir)
-        except(IOError, OSError):
+        except (IOError, OSError):
             return False
         return True
 
@@ -130,7 +129,7 @@ class LocalRepository(object):
         """Set the protection mark in a container or image tag"""
         try:
             # touch create version file
-            open(directory + "/PROTECT", 'w', encoding='utf-8').close()
+            open(directory + "/PROTECT", 'w').close()
             return True
         except (IOError, OSError):
             return False
@@ -178,8 +177,7 @@ class LocalRepository(object):
             container_dir = self.containersdir + '/' + fname
             if os.path.isdir(container_dir):
                 try:
-                    filep = open(container_dir + "/imagerepo.name", 'r',
-                                 encoding='utf-8')
+                    filep = open(container_dir + "/imagerepo.name", 'r')
                 except (IOError, OSError):
                     reponame = ""
                 else:
@@ -205,8 +203,8 @@ class LocalRepository(object):
                 self.del_container_name(name)  # delete aliases links
             if force:
                 FileUtil(container_dir).rchmod(stat.S_IWUSR | stat.S_IRUSR,
-                                                stat.S_IWUSR | stat.S_IRUSR |
-                                                stat.S_IXUSR)
+                                               stat.S_IWUSR | stat.S_IRUSR |
+                                               stat.S_IXUSR)
             if FileUtil(container_dir).remove(recursive=True):
                 self.cur_containerdir = ""
                 return True
@@ -293,8 +291,7 @@ class LocalRepository(object):
             return ""
         try:
             os.makedirs(container_dir + "/ROOT")
-            out_imagerepo = open(container_dir + "/imagerepo.name", 'w',
-                                 encoding='utf-8')
+            out_imagerepo = open(container_dir + "/imagerepo.name", 'w')
         except (IOError, OSError):
             return None
         else:
@@ -460,7 +457,7 @@ class LocalRepository(object):
             if not os.path.exists(directory):
                 os.makedirs(directory)
             self.cur_tagdir = directory
-            out_tag = open(directory + "/TAG", 'w', encoding='utf-8')
+            out_tag = open(directory + "/TAG", 'w')
         except (IOError, OSError):
             return False
         else:
@@ -492,7 +489,7 @@ class LocalRepository(object):
                     return False
         try:
             # Create version file
-            open(directory + "/" + version, 'a', encoding='utf-8').close()
+            open(directory + "/" + version, 'a').close()
         except (IOError, OSError):
             return False
         return True
@@ -582,7 +579,7 @@ class LocalRepository(object):
             out_filename = self.cur_tagdir + "/" + filename
         outfile = None
         try:
-            outfile = open(out_filename, 'w', encoding='utf-8')
+            outfile = open(out_filename, 'w')
             json.dump(data, outfile)
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             if outfile:
@@ -609,7 +606,7 @@ class LocalRepository(object):
         json_obj = None
         infile = None
         try:
-            infile = open(in_filename, 'r', encoding='utf-8')
+            infile = open(in_filename, 'r')
             json_obj = json.load(infile)
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             pass
@@ -644,13 +641,14 @@ class LocalRepository(object):
                     elif ':' in fname:
                         structure["repolayers"][layer_id]["layer_f"] = f_path
                     else:
-                        Msg().out("Warning: unkwnon file in layer:", f_path,
+                        Msg().out("Warning: unknown file in layer:", f_path,
                                   l=Msg.WAR)
-                elif fname in ("TAG", "v1", "v2", "PROTECT", "container.json"):
+                elif fname in ("TAG", "v1", "v2", "PROTECT", "container.json",
+                               "ancestry", "manifest"):
                     pass
 
                 else:
-                    Msg().out("Warning: unkwnon file in image:", f_path, l=Msg.WAR)
+                    Msg().out("Warning: unknown file in image:", f_path, l=Msg.WAR)
 
         return structure
 
@@ -788,7 +786,10 @@ class LocalRepository(object):
         if "ancestry" in structure and "has_json_f" in structure:
             status = self._verify_image_v1(structure)
         elif "manifest" in structure:
-            if "fsLayers" in structure["manifest"]:
+            if not structure["manifest"]:
+                Msg().err("Error: manifest is empty")
+                status = False
+            elif "fsLayers" in structure["manifest"]:
                 status = self._verify_image_v2_s1(structure)
             elif "layers" in structure["manifest"]:
                 status = self._verify_image_v2_s2(structure)
