@@ -15,9 +15,9 @@ class Uvolume(object):
         for char in str(path):
             if not clean_path:
                 clean_path = char
-            else:
-                if not (char == p_char and char == '/'):
-                    clean_path += char
+            elif not (char == p_char and char == '/'):
+                clean_path += char
+
             p_char = char
 
         if clean_path == "/":
